[][src]Module pushrod_render::render

The rendering logic library.

Modules

main
widget

This is the Widget and BaseWidget definitions for Widget objects to be defined by the pushrod project, and other crates that may define or create their own Widgets.

widget_config

This is a configuration object that stores information about Widgets.