[][src]Struct pushrod_render::render::widget::BaseWidget

pub struct BaseWidget { /* fields omitted */ }

This is an example top-level Widget object that is used to draw a background and a border of specified colors. COLOR_BASE determines the background fill color, and the COLOR_BORDER determines the color of the border. The width of the border is controlled by the get_config().border_width property.

Methods

impl BaseWidget[src]

Base top-level implementation of the BaseWidget, which other classes can extend.

pub fn new(x: i32, y: i32, w: u32, h: u32) -> Self[src]

Constructs a new base widget, given the points of origin and size.