This is a configuration object that stores information about Widgets.
| WidgetConfig | This is the store for the WidgetConfig, which each Widget object needs. This stores
information about the Widget. It currently contains the point of origin, size, a HashMap of
different Colors, a border width, and an invalidation flag.
|
| COLOR_BASE | Widget Base Color key for colors HashMap. This is the base fill color of a Widget
that is in an unselected state.
|
| COLOR_BORDER | Widget Border Color key for colors HashMap. This should be used for the color of the
border, if the Widget draws a border.
|
| COLOR_SECONDARY | Widget Secondary Color key for colors HashMap. This is the color the Widget should
display for any secondary properties, such as a fill color for a progress widget, a spinner,
etc.
|
| COLOR_SELECTED | Widget Selected Color key for colors HashMap. This is the color the Widget should
display when in selected state.
|
| COLOR_TEXT | Widget Text Color key for colors HashMap. This should be the color for the text being
displayed inside the Widget.
|